import { useEffect } from "react";
import { Link } from "wouter";
import Header from "@/components/header";
import Hero from "@/components/hero";
import Stats from "@/components/stats";
import LogoSlider from "@/components/logo-slider";
import Services from "@/components/services";
import AISolutions from "@/components/ai-solutions";
import Testimonials from "@/components/testimonials";
import ProcessTimeline from "@/components/process-timeline";
import FAQ from "@/components/faq";
import Projects from "@/components/projects";
import About from "@/components/about";
import Footer from "@/components/footer";
import SimpleChat from "@/components/simple-chat";


// FAQ Schema for SEO
const faqSchema = {
  "@context": "https://schema.org",
  "@type": "FAQPage",
  "mainEntity": [
    {
      "@type": "Question",
      "name": "Какво представляват AI решенията, които предлагате?",
      "acceptedAnswer": {
        "@type": "Answer",
        "text": "Нашите AI решения са персонализирани системи за автоматизация, анализ и оптимизация на бизнес процеси според нуждите на вашата компания."
      }
    },
    {
      "@type": "Question",
      "name": "Колко време отнема внедряването на AI в моя бизнес?",
      "acceptedAnswer": {
        "@type": "Answer",
        "text": "Времето за внедряване зависи от сложността на проекта, но обикновено процесът отнема между 4 и 12 седмици."
      }
    },
    {
      "@type": "Question",
      "name": "Могат ли AI решенията да се интегрират със съществуващите ми платформи?",
      "acceptedAnswer": {
        "@type": "Answer",
        "text": "Да, разработваме индивидуални конектори и осигуряваме пълна интеграция с най-популярните бизнес платформи."
      }
    },
    {
      "@type": "Question",
      "name": "Какви са изискванията за сигурност на вашите AI продукти?",
      "acceptedAnswer": {
        "@type": "Answer",
        "text": "Всички наши AI решения покриват най-високите стандарти за сигурност и могат да работят с локално внедряване за пълен контрол върху данните."
      }
    },
    {
      "@type": "Question",
      "name": "Каква е цената на вашите услуги?",
      "acceptedAnswer": {
        "@type": "Answer",
        "text": "Предлагаме прозрачни абонаментни планове, които започват от 250 EUR на месец, в зависимост от обхвата и нуждите на вашия бизнес."
      }
    },
    {
      "@type": "Question",
      "name": "Предлагате ли техническа поддръжка след внедряването?",
      "acceptedAnswer": {
        "@type": "Answer",
        "text": "Да, осигуряваме 24/7 техническа поддръжка и редовни актуализации за всички наши AI решения."
      }
    },
    {
      "@type": "Question",
      "name": "Подходящи ли са вашите решения за малки и средни предприятия?",
      "acceptedAnswer": {
        "@type": "Answer",
        "text": "Абсолютно! Разработваме мащабируеми решения, подходящи за компании с над 30 служители, независимо от размера."
      }
    },
    {
      "@type": "Question",
      "name": "Какво прави вашите AI решения различни от конкуренцията?",
      "acceptedAnswer": {
        "@type": "Answer",
        "text": "Фокусираме се върху персонализирани решения, локално внедряване за пълна сигурност и прозрачно ценообразуване без скрити такси."
      }
    }
  ]
};

export default function Home() {
  useEffect(() => {
    // Setup scroll animations
    const observerOptions = {
      threshold: 0.1,
      rootMargin: '0px 0px -50px 0px'
    };

    const observer = new IntersectionObserver((entries) => {
      entries.forEach((entry) => {
        if (entry.isIntersecting) {
          entry.target.classList.add('visible');
        }
      });
    }, observerOptions);

    const animateElements = document.querySelectorAll('.fade-in');
    animateElements.forEach((el) => {
      observer.observe(el);
    });

    return () => {
      animateElements.forEach((el) => {
        observer.unobserve(el);
      });
    };
  }, []);

  return (
    <>
      <Header />
      <main>
        <Hero />
        <Stats />
        <LogoSlider />
        <Services />
        <AISolutions />
        <Testimonials />
        <ProcessTimeline />
        <FAQ />
        <Projects />
        <About />

        {/* CTA Section */}
        <section className="py-20 px-4 bg-gradient-to-r from-purple-600 to-blue-600 text-white">
          <div className="max-w-4xl mx-auto text-center">
            <h2 className="text-4xl md:text-5xl font-bold mb-6 fade-in">
              Готови за дигитална трансформация?
            </h2>
            <p className="text-xl mb-8 opacity-90 fade-in">
              Свържете се с нас за безплатна консултация и персонализирана оферта
            </p>
            <Link href="/contact">
              <button className="bg-white text-purple-600 px-8 py-4 rounded-full text-lg font-semibold hover:bg-gray-100 transition-all transform hover:scale-105 fade-in">
                Безплатна консултация
              </button>
            </Link>
          </div>
        </section>
      </main>
      <Footer />
      <SimpleChat />

      
      {/* FAQ Schema Markup for SEO */}
      <script
        type="application/ld+json"
        dangerouslySetInnerHTML={{
          __html: JSON.stringify(faqSchema),
        }}
      />
    </>
  );
}
